OctoPrint Slack Integration
===========================

Send messages to your group's Slack chat when printing events happen!
You need to set up an [Incoming Webhook](https://my.slack.com/services/new/incoming-webhook) integration on the Slack side to use this.

Features
--------

* Select which events you want to trigger a chat notification for
* Customizable messages for each event
* Customize bot icon and username in Slack chat
* Sends elapsed time of print after finished

Screenshots
-----------

![Slack chat with messages from plugin.](/screenshots/slack.png?raw=true)
![Plugin settings screenshot.](/screenshots/settings.png?raw=true)
![Plugin settings screenshot.](/screenshots/settings2.png?raw=true)

Installation
------------

Follow the instructions provided by [OctoPrint](http://plugins.octoprint.org/help/installation/).
